=== modified file 'bzrlib/bundle/serializer/v07.py'
--- bzrlib/bundle/serializer/v07.py	2006-05-30 15:18:12 +0000
+++ bzrlib/bundle/serializer/v07.py	2006-06-10 22:13:45 +0000
@@ -177,15 +177,15 @@
                 base_tree = last_rev_tree
             else:
                 base_tree = self.source.revision_tree(base_id)
-
+            force_binary = (i != 0)
             self._write_revision(rev, rev_tree, base_id, base_tree, 
-                                 explicit_base)
+                                 explicit_base, force_binary)
 
             last_rev_id = base_id
             last_rev_tree = base_tree
 
     def _write_revision(self, rev, rev_tree, base_rev, base_tree, 
-                        explicit_base):
+                        explicit_base, force_binary):
         """Write out the information for a revision."""
         def w(key, value):
             self._write(key, value, indent=1)
@@ -195,7 +195,7 @@
         w('date', format_highres_date(rev.timestamp, rev.timezone))
         self.to_file.write('\n')
 
-        self._write_delta(rev_tree, base_tree, rev.revision_id)
+        self._write_delta(rev_tree, base_tree, rev.revision_id, force_binary)
 
         w('revision id', rev.revision_id)
         w('sha1', StrictTestament.from_revision(self.source, 
@@ -222,13 +222,14 @@
         self.to_file.write(' // '.join(p_texts).encode('utf-8'))
         self.to_file.write('\n')
 
-    def _write_delta(self, new_tree, old_tree, default_revision_id):
+    def _write_delta(self, new_tree, old_tree, default_revision_id, 
+                     force_binary):
         """Write out the changes between the trees."""
         DEVNULL = '/dev/null'
         old_label = ''
         new_label = ''
 
-        def do_diff(file_id, old_path, new_path, action):
+        def do_diff(file_id, old_path, new_path, action, force_binary):
             def tree_lines(tree, require_text=False):
                 if file_id in tree:
                     tree_file = tree.get_file(file_id)
@@ -239,6 +240,8 @@
                     return []
 
             try:
+                if force_binary:
+                    raise errors.BinaryFile()
                 old_lines = tree_lines(old_tree, require_text=True)
                 new_lines = tree_lines(new_tree, require_text=True)
                 action.write(self.to_file)
@@ -262,7 +265,7 @@
             if text_modified and kind == "symlink":
                 action.add_property('target', entry.symlink_target)
             if text_modified and kind == "file":
-                do_diff(file_id, old_path, new_path, action)
+                do_diff(file_id, old_path, new_path, action, force_binary)
             else:
                 action.write(self.to_file)
 

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-05-30 15:18:12 +0000
+++ bzrlib/tests/__init__.py	2006-06-10 22:13:45 +0000
@@ -450,6 +450,12 @@
             raise AssertionError('pattern "%s" not found in "%s"'
                     % (needle_re, haystack))
 
+    def assertNotContainsRe(self, haystack, needle_re):
+        """Assert that a does not match a regular expression"""
+        if re.search(needle_re, haystack):
+            raise AssertionError('pattern "%s" found in "%s"'
+                    % (needle_re, haystack))
+
     def assertSubset(self, sublist, superlist):
         """Assert that every entry in sublist is present in superlist."""
         missing = []

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2006-06-06 17:56:39 +0000
+++ bzrlib/tests/test_bundle.py	2006-06-10 22:13:45 +0000
@@ -662,3 +662,24 @@
                           verbose=False)
         self.tree1.commit(u'Merge', rev_id='a@lmod-0-4')
         bundle = self.get_valid_bundle('a@lmod-0-2a', 'a@lmod-0-4')
+
+    def test_hide_history(self):
+        import os, sys
+        pjoin = os.path.join
+
+        self.tree1 = BzrDir.create_standalone_workingtree('b1')
+        self.b1 = self.tree1.branch
+
+        open(pjoin('b1/one'), 'wb').write('one\n')
+        self.tree1.add('one')
+        self.tree1.commit('add file', rev_id='a@cset-0-1')
+        open(pjoin('b1/one'), 'wb').write('two\n')
+        self.tree1.commit('modify', rev_id='a@cset-0-2')
+        open(pjoin('b1/one'), 'wb').write('three\n')
+        self.tree1.commit('modify', rev_id='a@cset-0-3')
+        bundle_file = StringIO()
+        rev_ids = write_bundle(self.tree1.branch.repository, 'a@cset-0-3',
+                               'a@cset-0-1', bundle_file)
+        self.assertNotContainsRe(bundle_file.getvalue(), 'two')
+        self.assertContainsRe(bundle_file.getvalue(), 'one')
+        self.assertContainsRe(bundle_file.getvalue(), 'three')

